@@ -75,9 +75,6 @@ class IA3Model(BaseTuner):
 
     prefix: str = "ia3_"
 
-    def __init__(self, model, config, adapter_name, low_cpu_mem_usage: bool = False):
-        super().__init__(model, config, adapter_name, low_cpu_mem_usage=low_cpu_mem_usage)
-
     @staticmethod
     def _create_new_module(ia3_config, adapter_name, target, **kwargs):
         # avoid eager bnb import
