@@ -26,10 +26,12 @@ from peft import (
     HRAConfig,
     IA3Config,
     LoraConfig,
+    MissConfig,
     OFTConfig,
     PrefixTuningConfig,
     PromptEncoderConfig,
     PromptTuningConfig,
+    ShiraConfig,
     TaskType,
     VBLoRAConfig,
     VeraConfig,
@@ -70,6 +72,14 @@ ALL_CONFIGS = [
             "task_type": "SEQ_2_SEQ_LM",
         },
     ),
+    (
+        MissConfig,
+        {
+            "target_modules": None,
+            "r": 2,
+            "task_type": "SEQ_2_SEQ_LM",
+        },
+    ),
     (
         FourierFTConfig,
         {
@@ -145,6 +155,15 @@ ALL_CONFIGS = [
             "task_type": "SEQ_2_SEQ_LM",
         },
     ),
+    (
+        ShiraConfig,
+        {
+            "r": 1,
+            "task_type": "SEQ_2_SEQ_LM",
+            "target_modules": None,
+            "init_weights": False,
+        },
+    ),
     (
         VBLoRAConfig,
         {
