@@ -24,11 +24,13 @@ from peft import (
     HRAConfig,
     IA3Config,
     LoraConfig,
+    MissConfig,
     OFTConfig,
     PrefixTuningConfig,
     PromptEncoderConfig,
     PromptLearningConfig,
     PromptTuningConfig,
+    ShiraConfig,
     VBLoRAConfig,
     VeraConfig,
 )
@@ -69,6 +71,14 @@ ALL_CONFIGS = [
             "r": 2,
         },
     ),
+    (
+        MissConfig,
+        {
+            "task_type": "FEATURE_EXTRACTION",
+            "target_modules": None,
+            "r": 2,
+        },
+    ),
     (
         FourierFTConfig,
         {
@@ -145,6 +155,15 @@ ALL_CONFIGS = [
             "num_virtual_tokens": 10,
         },
     ),
+    (
+        ShiraConfig,
+        {
+            "r": 1,
+            "task_type": "FEATURE_EXTRACTION",
+            "target_modules": None,
+            "init_weights": False,
+        },
+    ),
     (
         VBLoRAConfig,
         {
